<?php

declare(strict_types=1);

namespace App\Controller\Payment;

use App\Request\BindCardRequest;
use App\Request\RegisterRequest;
use App\Request\UnbindCardRequest;
use Hyperf\HttpServer\Contract\RequestInterface;
use App\Service\PaymentService;
use App\Service\UserService;
use Hyperf\Context\Context;

class PayController extends AbstractController
{
    private UserService $userService;
    private PaymentService $paymentService;
    
    public function __construct(PaymentService $paymentService, UserService $userService)
    {
        $this->userService = $userService;
        $this->paymentService = $paymentService;
    }

    private function parseReqest($request, $requestClass)
    {
        $app = Context::get('app');
        $requestLog = Context::get('requestLog');
        $req = new $requestClass($request->all());
        return [$app, $req->getData(), $requestLog->request_token];
    }

    public function companyRegister(RequestInterface $request)
    {
        [$app, $data, $token] = $this->parseReqest($request, RegisterRequest::class);
        $result = $this->userService->companyRegister($data, $app, $token);
        return $this->success(['result' => $result]);
    }

    public function register(RequestInterface $request)
    {
        [$app, $data, $token] = $this->parseReqest($request, RegisterRequest::class);
        $url = $this->userService->register($data, $app, $token);
        return $this->success(['url' => $url]);
    }

    public function bindCard(RequestInterface $request)
    {
        [$app, $data, $token] = $this->parseReqest($request, BindCardRequest::class);
        $url = $this->userService->bindCard($data, $app, $token);
        return $this->success(['url' => $url]);
    }

    public function unbindCard(RequestInterface $request)
    {
        [$app, $data, $token] = $this->parseReqest($request, UnbindCardRequest::class);
        $data = $this->userService->unbindCard($data, $app);
        return $this->success($data);
    }

    public function pwdForget(RequestInterface $request)
    {
        [$app, $data, $token] = $this->parseReqest($request, UnbindCardRequest::class);
        $url = $this->userService->unbindCard($data, $app, $token);
        return $this->success(['url' => $url]);
    }

    public function pwdModify(RequestInterface $request)
    {
        [$app, $data, $token] = $this->parseReqest($request, UnbindCardRequest::class);
        $url = $this->userService->unbindCard($data, $app, $token);
        return $this->success(['url' => $url]);
    }

    public function payment(RequestInterface $request) {
        [$app, $data, $token] = $this->parseReqest($request, UnbindCardRequest::class);
        $data = $this->paymentService->payment($data, $app, $token);
        return $this->success($data);
    }

    public function refundApply(RequestInterface $request)
    {
        [$app, $data, $token] = $this->parseReqest($request, UnbindCardRequest::class);
        $data = $this->paymentService->refundApply($app, $data);
        return $this->success($data);
    }

    public function refundConfirm(RequestInterface $request)
    {
        [$app, $data, $token] = $this->parseReqest($request, UnbindCardRequest::class);
        $data = $this->paymentService->refundApply($app, $data);
        return $this->success($data);
    }

    public function refundCancel(RequestInterface $request)
    {
        [$app, $data, $token] = $this->parseReqest($request, UnbindCardRequest::class);
        $data = $this->paymentService->refundApply($app, $data);
        return $this->success($data);
    }
}
